HtmlDiagnose
===============
A weeb page HTML format diagnoser

Install
===============
::

 pip install HtmlDiagnose


Use
===============
cd to you working directory and run command:

::

 HtmlDiagnose http://www.baidu.com

on Windows use:
::

 HtmlDiagnose http://www.baidu.com

if can't find HtmlDiagnose command, try:
::

 python -m HtmlDiagnose http://www.baidu.com

